couchsurfing-python
===================

Couchsurfing.org Python API

Usage:
------

* Initialize API with couchsurfing.org username and password::

	from couchsurfing import Api
	api = Api(login, password)

* Get you user profile::

	api.get_profile()


.. image:: https://travis-ci.org/nderkach/couchsurfing-python.png
   :target: https://travis-ci.org/nderkach/couchsurfing-python


